<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>RemoveBlock</name>
    <message>
        <location filename="../RemoveBlockInit.js" line="+2"/>
        <source>&amp;Remove Block</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Usuń blok</translatorcomment>
        <translation>&amp;Usuń blok</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Delete selected block</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Usuń wybrany blok</translation>
    </message>
</context>
</TS>
